@@ -27,23 +27,7 @@ type configuration struct {
 	port     string
 	password string
 	resource string
-}
-
-func rcvStanzas(client *xmpp.Client, iqc chan xmpp.IQ, msgc chan xmpp.Chat) {
-	for {
-		received, err := client.Recv()
-		if err != nil {
-			log.Println(err)
-		}
-		switch v := received.(type) {
-		case xmpp.Chat:
-			msgc <- v
-		case xmpp.IQ:
-			iqc <- v
-		case xmpp.Presence:
-		default:
-		}
-	}
+	alias    string
 }
 
 func readMessage(messageFilePath string) (string, error) {
@@ -93,10 +77,10 @@ func main() {
 	}
 
 	var (
-		err                                       error
-		message, user, server, password, resource string
-		oxPrivKey                                 *crypto.Key
-		recipients                                []recipientsType
+		err                                              error
+		message, user, server, password, resource, alias string
+		oxPrivKey                                        *crypto.Key
+		recipients                                       []recipientsType
 	)
 
 	// Define command line flags.
@@ -109,7 +93,9 @@ func main() {
 	flagChatroom := getopt.BoolLong("chatroom", 'c', "Send message to a chatroom.")
 	flagDirectTLS := getopt.BoolLong("tls", 't', "Use direct TLS.")
 	flagResource := getopt.StringLong("resource", 'r', "", "Set resource. "+
-		"When sending to a chatroom this is used as 'alias'.")
+		"When sending to a chatroom this is used as 'alias'. DEPRECATED: Use --alias instead.")
+	flagAlias := getopt.StringLong("alias", 'a', "", "Set alias/nickname"+
+		"for chatrooms.")
 	flagFile := getopt.StringLong("file", 'f', "", "Set configuration file. (Default: "+
 		"~/.config/go-sendxmpp/sendxmpprc)")
 	flagMessageFile := getopt.StringLong("message", 'm', "", "Set file including the message.")
@@ -185,6 +171,7 @@ func main() {
 		server = config.jserver
 		password = config.password
 		resource = config.resource
+		alias = config.alias
 		if config.port != "" {
 			server = net.JoinHostPort(server, fmt.Sprint(config.port))
 		}
@@ -205,11 +192,29 @@ func main() {
 		password = *flagPassword
 	}
 
-	// Overwrite resource if specified via command line flag
+	switch {
+	// Use the resource as alias if no alias is specified otherwise but a resource is specified.
+	// Backward compat, will be removed when resource is removed.
+	case alias == "" && *flagAlias == "" && *flagResource != "":
+		alias = *flagResource
+		// Use the resource as alias if no alias is specified otherwise but a resource is specified.
+		// Backward compat, will be removed when resource is removed.
+	case alias == "" && *flagAlias == "" && resource != "":
+		alias = resource
+	// Use "go-sendxmpp" if no nick is specified via config or command line flag.
+	case alias == "" && *flagAlias == "":
+		alias = "go-sendxmpp"
+		// Overwrite configured alias if a nick is specified via command line flag.
+	case *flagAlias != "":
+		alias = *flagAlias
+	}
+
+	// Overwrite resource if specified via command line flag.
 	if *flagResource != "" {
+		fmt.Println("Deprecated flag: --resource.")
 		resource = *flagResource
 	} else if resource == "" {
-		// Use "go-sendxmpp" plus a random string if no other resource is specified
+		// Use "go-sendxmpp" plus a random string if no other resource is specified.
 		resource = "go-sendxmpp." + getShortID()
 	}
 
@@ -262,6 +267,39 @@ func main() {
 		}
 	}
 
+	// Skip reading message if '-i' or '--interactive' is set to work with e.g. 'tail -f'.
+	// Also for listening mode.
+	if !*flagInteractive && !*flagListen && *flagHTTPUpload == "" {
+		if message == "" {
+
+			scanner := bufio.NewScanner(os.Stdin)
+			for scanner.Scan() {
+
+				if message == "" {
+					message = scanner.Text()
+				} else {
+					message = message + "\n" + scanner.Text()
+				}
+			}
+
+			if err := scanner.Err(); err != nil {
+				if err != io.EOF {
+					log.Fatal(err)
+				}
+			}
+		}
+	}
+
+	// Remove invalid code points.
+	message = strings.ToValidUTF8(message, "")
+	reg := regexp.MustCompile(`[\x{0000}-\x{0008}\x{000B}\x{000C}\x{000E}-\x{001F}]`)
+	message = reg.ReplaceAllString(message, "")
+
+	// Exit if message is empty.
+	if message == "" && !*flagInteractive && !*flagListen && *flagHTTPUpload == "" {
+		os.Exit(0)
+	}
+
 	// Connect to server.
 	client, err := connect(options, *flagDirectTLS)
 	if err != nil {
@@ -279,7 +317,7 @@ func main() {
 			re.OxKeyRing, err = oxGetPublicKeyRing(client, iqc, r)
 			if err != nil {
 				re.OxKeyRing = nil
-				fmt.Println("Couldn't receive key for:", r)
+				fmt.Println("ox: error fetching key for", r+":", err)
 			}
 		}
 		recipients = append(recipients, re)
@@ -352,34 +390,6 @@ func main() {
 			*flagHTTPUpload)
 	}
 
-	// Skip reading message if '-i' or '--interactive' is set to work with e.g. 'tail -f'.
-	// Also for listening mode.
-	if !*flagInteractive && !*flagListen {
-		if message == "" {
-
-			scanner := bufio.NewScanner(os.Stdin)
-			for scanner.Scan() {
-
-				if message == "" {
-					message = scanner.Text()
-				} else {
-					message = message + "\n" + scanner.Text()
-				}
-			}
-
-			if err := scanner.Err(); err != nil {
-				if err != io.EOF {
-					log.Fatal(err)
-				}
-			}
-		}
-	}
-
-	// Remove invalid code points.
-	message = strings.ToValidUTF8(message, "")
-	reg := regexp.MustCompile(`[\x{0000}-\x{0008}\x{000B}\x{000C}\x{000E}-\x{001F}]`)
-	message = reg.ReplaceAllString(message, "")
-
 	var msgType string
 	msgType = "chat"
 	if *flagChatroom {
@@ -388,10 +398,10 @@ func main() {
 		for _, recipient := range recipients {
 			if *flagMUCPassword != "" {
 				dummyTime := time.Now()
-				_, err = client.JoinProtectedMUC(recipient.Jid, resource,
+				_, err = client.JoinProtectedMUC(recipient.Jid, alias,
 					*flagMUCPassword, xmpp.NoHistory, 0, &dummyTime)
 			} else {
-				_, err = client.JoinMUCNoHistory(recipient.Jid, resource)
+				_, err = client.JoinMUCNoHistory(recipient.Jid, alias)
 			}
 			if err != nil {
 				log.Fatal(err)
@@ -400,17 +410,30 @@ func main() {
 	}
 	switch {
 	case *flagRaw:
+		if message == "" {
+			break
+		}
 		// Send raw XML
-		_, err = client.SendOrg(message)
+		_, err = client.SendOrg(message + "\n")
 		if err != nil {
 			log.Fatal(err)
 		}
 	case *flagInteractive:
 		// Send in endless loop (for usage with e.g. "tail -f").
+		var reader = bufio.NewReader(os.Stdin)
 		for {
-			scanner := bufio.NewScanner(os.Stdin)
-			scanner.Scan()
-			message = scanner.Text()
+			message, err = reader.ReadString('\n')
+			if err != nil {
+				log.Fatal("failed to read from stdin")
+			}
+
+			// Remove invalid code points.
+			message = strings.ToValidUTF8(message, "")
+			reg := regexp.MustCompile(`[\x{0000}-\x{0008}\x{000B}\x{000C}\x{000E}-\x{001F}]`)
+			message = reg.ReplaceAllString(message, "")
+			if message == "" {
+				continue
+			}
 			for _, recipient := range recipients {
 				switch {
 				case *flagOx:
@@ -424,7 +447,7 @@ func main() {
 							recipient.Jid)
 						continue
 					}
-					_, err = client.SendOrg(oxMessage)
+					_, err = client.SendOrg(oxMessage + "\n")
 					if err != nil {
 						log.Fatal(err)
 					}
@@ -508,6 +531,9 @@ func main() {
 		}
 	default:
 		for _, recipient := range recipients {
+			if message == "" {
+				break
+			}
 			switch {
 			case *flagHTTPUpload != "":
 				_, err = client.Send(xmpp.Chat{Remote: recipient.Jid,
@@ -526,7 +552,7 @@ func main() {
 					fmt.Println("Ox: couldn't encrypt to", recipient.Jid)
 					continue
 				}
-				_, err = client.SendOrg(oxMessage)
+				_, err = client.SendOrg(oxMessage + "\n")
 				if err != nil {
 					log.Fatal(err)
 				}
