@@ -511,11 +511,26 @@ func oxRecvPublicKeys(client *xmpp.Client, iqc chan xmpp.IQ, recipient string,
 		return nil, err
 	}
 	oxPublicKeyXMLPubsub := oxPublicKeyXML.SelectElement("pubsub")
+	if oxPublicKeyXMLPubsub == nil {
+		return nil, errors.New("ox: no pubsub element in reply to public " +
+			"key request")
+	}
 	oxPublicKeyXMLItems := oxPublicKeyXMLPubsub.SelectElement("items")
+	if oxPublicKeyXMLItems == nil {
+		return nil, errors.New("ox: no items element in reply to public " +
+			"key request")
+	}
 	oxPublicKeyXMLItem := oxPublicKeyXMLItems.SelectElement("item")
+	if oxPublicKeyXMLItem == nil {
+		return nil, errors.New("ox: no item element in reply to public " +
+			"key request")
+	}
 	oxPublicKeyXMLPubkeys := oxPublicKeyXMLItem.SelectElements("pubkey")
 	for _, r := range oxPublicKeyXMLPubkeys {
 		data := r.SelectElement("data")
+		if data == nil {
+			continue
+		}
 		decodedPubKey, err := base64.StdEncoding.DecodeString(data.Text())
 		if err != nil {
 			return nil, err
@@ -573,14 +588,32 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ,
 	}
 
 	oxPubKeyListXMLPubsub := oxPubKeyListXML.SelectElement("pubsub")
+	if oxPubKeyListXMLPubsub == nil {
+		return nil, errors.New("ox: no pubsub element in public key list")
+	}
 	oxPubKeyListXMLPubsubItems := oxPubKeyListXMLPubsub.SelectElement("items")
+	if oxPubKeyListXMLPubsubItems == nil {
+		return nil, errors.New("ox: no items element in public key list")
+	}
 	oxPubKeyListXMLPubsubItemsItem := oxPubKeyListXMLPubsubItems.SelectElement("item")
+	if oxPubKeyListXMLPubsubItemsItem == nil {
+		return nil, errors.New("ox: no item element in public key list")
+	}
 	oxPubKeyListXMLPubsubItemsItemPkl := oxPubKeyListXMLPubsubItemsItem.SelectElement("public-keys-list")
+	if oxPubKeyListXMLPubsubItemsItemPkl == nil {
+		return nil, errors.New("ox: no keblic-keys-list element")
+	}
 	oxPubKeyListXMLPubsubItemsItemPklPm :=
 		oxPubKeyListXMLPubsubItemsItemPkl.SelectElements("pubkey-metadata")
 	for _, r := range oxPubKeyListXMLPubsubItemsItemPklPm {
 		date := r.SelectAttr("date")
+		if date == nil {
+			continue
+		}
 		fingerprint := r.SelectAttr("v4-fingerprint")
+		if fingerprint == nil {
+			continue
+		}
 		keyDate, err := time.Parse(time.RFC3339, date.Value)
 		if err != nil {
 			return nil, err
@@ -662,6 +695,9 @@ func oxGetPublicKeyRing(client *xmpp.Client, iqc chan xmpp.IQ,
 
 func oxEncrypt(client *xmpp.Client, iqc chan xmpp.IQ, oxPrivKey *crypto.Key,
 	recipient string, keyRing *crypto.KeyRing, message string) (string, error) {
+	if message == "" {
+		return "", nil
+	}
 	privKeyRing, err := crypto.NewKeyRing(oxPrivKey)
 	if err != nil {
 		return "error", err
